from distutils.core import setup
setup(
    name = 'pangeamt_toolkit',
    packages = ['pangeamt_toolkit', 'pangeamt_toolkit.onmt',
        'pangeamt_toolkit.onmt.encoders', 'pangeamt_toolkit.onmt.decoders',
        'pangeamt_toolkit.onmt.inputters', 'pangeamt_toolkit.onmt.models',
        'pangeamt_toolkit.onmt.utils', 'pangeamt_toolkit.pangeanmt',
        'pangeamt_toolkit.pangeanmt.extended_model',
        'pangeamt_toolkit.pangeanmt.request_handler', 'pangeamt_toolkit.seg',
        'pangeamt_toolkit.processors'],
    scripts = ['bin/pangeamt_file_postprocess.py', 'bin/pangeamt_train.py',
    'bin/pangeamt_file_preprocess.py', 'bin/pangeamt_preprocess.py',
    'bin/pangeamt_translate.py'],
    version = '1.7',
    license='MIT',
    description = 'PANGEAMT-TOOLKIT',
    author = 'PANGEAMT',
    author_email = 'a.cerda@pangeanic.es',
    url = 'https://github.com/Pangeamt/pangeamt_toolkit',
    download_url = 'https://github.com/Pangeamt/pangeamt_toolkit/archive/1.7.tar.gz',
    install_requires=[
        'aiohttp',
        'async-timeout',
        'attrs',
        'certifi',
        'chardet',
        'Click',
        'ConfigArgParse',
        'future',
        'idna',
        'idna-ssl',
        'jieba',
        'joblib',
        'mecab-python3',
        'multidict',
        'numpy',
        'PyYAML',
        'requests',
        'sacremoses',
        'six',
        'subword-nmt',
        'torch',
        'torchtext',
        'tqdm',
        'typing-extensions',
        'urllib3',
        'uvloop',
        'yarl'
    ]
)
